<?php
/**
 * veroxa functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package veroxa
 */

if ( ! defined( 'VEROXA_VERSION' ) ) {
	define( 'VEROXA_VERSION', '1.1.5' );
}

if ( ! defined( 'VEROXA_INCLUDES_DIR' ) ) {
	define( 'VEROXA_INCLUDES_DIR', trailingslashit( get_template_directory() ) . 'inc/' );
}

require_once( VEROXA_INCLUDES_DIR . 'setup.php' );

/**
 * Register Google fonts
 *
 * @return string Encoded Google fonts URL
 */
if ( ! function_exists( 'veroxa_fonts' ) ) {

	function veroxa_fonts() {
		$fonts_url = '';
		$fonts     = array();
		$subsets   = 'latin,latin-ext';

		$fonts[] = 'Open Sans:400,700';
		$fonts[] = 'Nunito Sans:400,700';

		if ( $fonts ) {
			$fonts_url = add_query_arg( array(
				'family' => urlencode( implode( '|', $fonts ) ),
				'subset' => urlencode( $subsets ),
			), 'https://fonts.googleapis.com/css' );
		}

		return $fonts_url;
	}
}

/**
 * Enqueue scripts and styles.
 */
function veroxa_scripts() {

	// Load Main Stylesheet
	wp_enqueue_style( 'veroxa-stylesheet', get_stylesheet_uri(), array() );

	// Add Google fonts
	wp_enqueue_style( 'veroxa-fonts', veroxa_fonts(), array(), null );

	// Font Awesome
	wp_enqueue_style( 'veroxa-fontawesome', get_template_directory_uri() . '/assets/font-awesome/css/font-awesome.min.css', array(), null );

	// Makes "skip to content" link work correctly
	wp_enqueue_script( 'veroxa-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array( 'jquery' ), null, true );

	// JS file for main navigation
	wp_enqueue_script( 'veroxa-script', get_template_directory_uri() . '/assets/js/navigation.js', array( 'jquery' ), null, true );

	wp_localize_script( 'veroxa-script', 'veroxaScreenReaderText', array(
		'expand'   => __( 'expand child menu', 'veroxa' ),
		'collapse' => __( 'collapse child menu', 'veroxa' ),
	) );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'veroxa_scripts' );

/**
 * Customizer additions.
 */
require_once( VEROXA_INCLUDES_DIR . 'customizer.php' );

/**
 * Custom template tags for this theme.
 */
require_once( VEROXA_INCLUDES_DIR . 'template-tags.php' );

/**
 * Load Jetpack compatibility file.
 */
require_once( VEROXA_INCLUDES_DIR . 'jetpack.php' );

/**
 * Load admin theme page.
 */
require_once( VEROXA_INCLUDES_DIR . 'theme-info.php' );
