<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package veroxa
 */
if ( ! function_exists( 'veroxa_site_branding' ) ) :
/**
	 * Show Site Branding
	 *
	 */
	function veroxa_site_branding() {

		// Display the Custom Logo
		if ( has_custom_logo() ) {

			the_custom_logo();

		} else {

			if ( is_front_page() && is_home() ) : ?>

			<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>

		<?php else : ?>

			<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>

		<?php endif;

		}

	}
	endif;

if ( ! function_exists( 'veroxa_social_media' ) ) :
	/**
	 * Show Social Media Icons
	 *
	 */
	function veroxa_social_media() {

		if ( get_theme_mod( 'social_media_twitter' ) ) { ?>
			<a href="<?php echo esc_url( get_theme_mod( 'social_media_twitter', '' ) ); ?>" class="social-icon" title="<?php sprintf( esc_html__( 'Twitter', 'veroxa' ) ); ?>"><i class="fa fa-twitter-square"></i></a>
			<?php
		}

		if ( get_theme_mod( 'social_media_facebook' ) ) { ?>
			<a href="<?php echo esc_url( get_theme_mod( 'social_media_facebook', '' ) ); ?>" class="social-icon" title="<?php sprintf( esc_html__( 'Facebook', 'veroxa' ) ); ?>"><i class="fa fa-facebook-square"></i></a>
			<?php
		}

		if ( get_theme_mod( 'social_media_googleplus' ) ) { ?>
			<a href="<?php echo esc_url( get_theme_mod( 'social_media_googleplus', '' ) ); ?>" class="social-icon" title="<?php sprintf( esc_html__( 'Google Plus', 'veroxa' ) ); ?>"><i class="fa fa-google-plus-square"></i></a>
			<?php
		}

		if ( get_theme_mod( 'social_media_pinterest' ) ) { ?>
			<a href="<?php echo esc_url( get_theme_mod( 'social_media_pinterest', '' ) ); ?>" class="social-icon" title="<?php sprintf( esc_html__( 'Pinterest', 'veroxa' ) ); ?>"><i class="fa fa-pinterest-square"></i></a>
			<?php
		}

		if ( get_theme_mod( 'social_media_youtube' ) ) { ?>
			<a href="<?php echo esc_url( get_theme_mod( 'social_media_youtube', '' ) ); ?>" class="social-icon" title="<?php sprintf( esc_html__( 'YouTube', 'veroxa' ) ); ?>"><i class="fa fa-youtube-square"></i></a>
			<?php
		}

		if ( get_theme_mod( 'social_media_instagram' ) ) { ?>
			<a href="<?php echo esc_url( get_theme_mod( 'social_media_instagram', '' ) ); ?>" class="social-icon" title="<?php sprintf( esc_html__( 'Instagram', 'veroxa' ) ); ?>"><i class="fa fa-instagram"></i></a>
			<?php
		}

		if ( get_theme_mod( 'social_media_linkedin' ) ) { ?>
			<a href="<?php echo esc_url( get_theme_mod( 'social_media_linkedin', '' ) ); ?>" class="social-icon" title="<?php sprintf( esc_html__( 'LinkedIn', 'veroxa' ) ); ?>"><i class="fa fa-linkedin-square"></i></a>
			<?php
		}

		if ( get_theme_mod( 'social_media_behance' ) ) { ?>
			<a href="<?php echo esc_url( get_theme_mod( 'social_media_behance', '' ) ); ?>" class="social-icon" title="<?php sprintf( esc_html__( 'Behance', 'veroxa' ) ); ?>"><i class="fa fa-behance-square"></i></a>
			<?php
		}

		if ( get_theme_mod( 'social_media_tumblr' ) ) { ?>
			<a href="<?php echo esc_url( get_theme_mod( 'social_media_tumblr', '' ) ); ?>" class="social-icon" title="<?php sprintf( esc_html__( 'Tumblr', 'veroxa' ) ); ?>"><i class="fa fa-tumblr-square"></i></a>
			<?php
		}

		if ( get_theme_mod( 'social_media_vimeo' ) ) { ?>
			<a href="<?php echo esc_url( get_theme_mod( 'social_media_vimeo', '' ) ); ?>" class="social-icon" title="<?php sprintf( esc_html__( 'Vimeo', 'veroxa' ) ); ?>"><i class="fa fa-vimeo-square"></i></a>
			<?php
		}

		if ( get_theme_mod( 'social_media_dribble' ) ) { ?>
			<a href="<?php echo esc_url( get_theme_mod( 'social_media_dribble', '' ) ); ?>" class="social-icon" title="<?php sprintf( esc_html__( 'Dribble', 'veroxa' ) ); ?>"><i class="fa fa-dribbble"></i></a>
			<?php
		}

}
 endif;

if ( ! function_exists( 'veroxa_entry_meta' ) ) :
	/**
	 * Show HTML with meta information for the date, author and categories.
	 *
	 */
	function veroxa_entry_meta() {

		// show meta date
		echo get_the_date();
		echo ' | ';

		// show meta author
		the_author_meta( 'display_name' );
		echo ' | ';

		// show meta categories
		the_category( ', ' );

}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function veroxa_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'veroxa_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'veroxa_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so veroxa_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so veroxa_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in veroxa_categorized_blog.
 */
function veroxa_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'veroxa_categories' );
}
add_action( 'edit_category', 'veroxa_category_transient_flusher' );
add_action( 'save_post',     'veroxa_category_transient_flusher' );
